@@ -25,13 +25,9 @@ import           Data.ByteString (ByteString)
 import qualified Data.ByteString as B
 import           Data.Char
 import           Data.Foldable
-import           Data.Function
 import           Data.Hashable
-import           Data.Monoid
-import           Data.Primitive.ByteArray
 import           Data.String
 import           Data.Text (Text)
-import qualified Data.Text as Text
 import qualified Data.Text.Encoding as Text
 import qualified Data.Vector.Primitive as PV
 import qualified Data.Primitive.ByteArray as BA
@@ -72,7 +68,7 @@ instance Ord Identifier where
 
 -- | Hash on normalized identifier
 instance Hashable Identifier where
-  hashWithSalt salt (Identifier _ b@(ByteArray arr)) =
+  hashWithSalt salt (Identifier _ b@(BA.ByteArray arr)) =
     hashByteArrayWithSalt arr 0 (BA.sizeofByteArray b) salt
 
 -- | @'fromString' = 'mkId' . 'fromString'
